@@ -40,6 +40,7 @@
 #include <sys/statfs.h>
 #include <sys/wait.h>
 #include <sys/fcntl.h>
+#include <pty.h>
 
 #define RAMFS_MAGIC     0x858458f6
 
@@ -179,12 +180,14 @@ void aptcc::cancel()
 }
 
 pair<pkgCache::PkgIterator, pkgCache::VerIterator>
-		      aptcc::find_package_id(const gchar *package_id)
+		      aptcc::find_package_id(const gchar *package_id, bool &found)
 {
 	gchar **parts;
 	pkgCache::VerIterator ver;
 	pair<pkgCache::PkgIterator, pkgCache::VerIterator> pkg_ver;
 
+    found = true;
+
 	parts = pk_package_id_split (package_id);
 	pkg_ver.first = packageCache->FindPkg(parts[PK_PACKAGE_ID_NAME]);
 
@@ -216,6 +219,7 @@ pair<pkgCache::PkgIterator, pkgCache::VerIterator>
 		return pkg_ver;
 	}
 
+    found = false;
 	g_strfreev (parts);
 	return pkg_ver;
 }
@@ -252,7 +256,8 @@ void aptcc::emit_package(const pkgCache::PkgIterator &pkg,
 {
 	// check the state enum to see if it was not set.
 	if (state == PK_INFO_ENUM_UNKNOWN) {
-		if (pkg->CurrentState == pkgCache::State::Installed) {
+        if (pkg->CurrentState == pkgCache::State::Installed &&
+            pkg.CurrentVer() == ver) {
 			state = PK_INFO_ENUM_INSTALLED;
 		} else {
 			state = PK_INFO_ENUM_AVAILABLE;
@@ -260,7 +265,7 @@ void aptcc::emit_package(const pkgCache::PkgIterator &pkg,
 	}
 
 	if (filters != 0) {
-		std::string str = ver.Section();
+		std::string str = ver.Section() == NULL ? "" : ver.Section();
 		std::string section, repo_section;
 
 		size_t found;
@@ -459,37 +464,50 @@ void aptcc::povidesCodec(vector<pair<pkgCache::PkgIterator, pkgCache::VerIterato
 }
 
 // used to emit packages it collects all the needed info
-void aptcc::emit_details(const pkgCache::PkgIterator &pkg)
+void aptcc::emit_details(const pkgCache::PkgIterator &pkg, const pkgCache::VerIterator &version)
 {
-	pkgCache::VerIterator ver = find_ver(pkg);
-	std::string section = ver.Section();
+    pkgCache::VerIterator ver;
+    if (version.end() == false) {
+        ver = version;
+    } else {
+        ver = find_ver(pkg);
+    }
+    std::string section = ver.Section() == NULL ? "" : ver.Section();
 
-	size_t found;
-	found = section.find_last_of("/");
-	section = section.substr(found + 1);
+    size_t found;
+    found = section.find_last_of("/");
+    section = section.substr(found + 1);
 
-	pkgCache::VerFileIterator vf = ver.FileList();
-	pkgRecords::Parser &rec = packageRecords->Lookup(vf);
+    pkgCache::VerFileIterator vf = ver.FileList();
+    pkgRecords::Parser &rec = packageRecords->Lookup(vf);
 
-	gchar *package_id;
-	package_id = pk_package_id_build(pkg.Name(),
-					 ver.VerStr(),
-					 ver.Arch(),
-					 vf.File().Archive() == NULL ? "" : vf.File().Archive());
-	pk_backend_details(m_backend,
-			   package_id,
-			   "unknown",
-			   get_enum_group(section),
-			   get_long_description_parsed(ver, packageRecords).c_str(),
-			   rec.Homepage().c_str(),
-			   ver->Size);
+    long size;
+    if (pkg->CurrentState == pkgCache::State::Installed && pkg.CurrentVer() == ver) {
+        // if the package is installed emit the installed size
+        size = ver->InstalledSize;
+    } else {
+        size = ver->Size;
+    }
+
+    gchar *package_id;
+    package_id = pk_package_id_build(pkg.Name(),
+                                     ver.VerStr(),
+                                     ver.Arch(),
+                                     vf.File().Archive() == NULL ? "" : vf.File().Archive());
+    pk_backend_details(m_backend,
+                       package_id,
+                       "unknown",
+                       get_enum_group(section),
+                       get_long_description_parsed(ver, packageRecords).c_str(),
+                       rec.Homepage().c_str(),
+                       size);
 }
 
 // used to emit packages it collects all the needed info
-void aptcc::emit_update_detail(const pkgCache::PkgIterator &pkg)
+void aptcc::emit_update_detail(const pkgCache::PkgIterator &pkg, const pkgCache::VerIterator &version)
 {
     // Get the version of the current package
-    pkgCache::VerIterator     currver = find_ver(pkg);
+    pkgCache::VerIterator currver = find_ver(pkg);
     pkgCache::VerFileIterator currvf  = currver.FileList();
     // Build a package_id from the current version
     gchar *current_package_id;
@@ -499,7 +517,12 @@ void aptcc::emit_update_detail(const pkgCache::PkgIterator &pkg)
                                              currvf.File().Archive() == NULL ? "" : currvf.File().Archive());
 
     // Get the update version
-    pkgCache::VerIterator candver = find_candidate_ver(pkg);
+    pkgCache::VerIterator candver;
+    if (version.end() == false) {
+        candver = version;
+    } else {
+        candver = find_candidate_ver(pkg);
+    }
 
     pkgCache::VerFileIterator vf = candver.FileList();
     string origin = vf.File().Origin() == NULL ? "" : vf.File().Origin();
@@ -518,7 +541,7 @@ void aptcc::emit_update_detail(const pkgCache::PkgIterator &pkg)
     if (origin.compare("Debian") == 0 || origin.compare("Ubuntu") == 0) {
         string prefix;
 
-        string src_section = candver.Section();
+        string src_section = candver.Section() == NULL ? "" : candver.Section();
         if(src_section.find('/') != src_section.npos) {
             src_section = string(src_section, 0, src_section.find('/'));
         } else {
@@ -600,8 +623,7 @@ void aptcc::emit_update_detail(const pkgCache::PkgIterator &pkg)
                            G_REGEX_MATCH_ANCHORED,
                            0);
     GRegex *regexDate;
-    regexDate = g_regex_new("^ -- (?'maintainer'.+) (?'mail'<.+>)  (?'dayname'\\w+,) "
-"(?'d'\\d+) (?'m'\\w+) (?'y'\\d+) (?'H'\\d+):(?'M'\\d+):(?'s'\\d+) (?'offset'[-\\+]\\d+)$",
+    regexDate = g_regex_new("^ -- (?'maintainer'.+) (?'mail'<.+>)  (?'date'.+)$",
                             G_REGEX_CASELESS,
                             G_REGEX_MATCH_ANCHORED,
                             0);
@@ -653,39 +675,15 @@ void aptcc::emit_update_detail(const pkgCache::PkgIterator &pkg)
             // and when it got updated
             GMatchInfo *match_info;
             if (g_regex_match(regexDate, str, G_REGEX_MATCH_ANCHORED, &match_info)) {
-                gchar *tz;
-                gchar *year;
-                gchar *month;
-                gchar *day;
-                gchar *hour;
-                gchar *minute;
-                gchar *seconds;
-                tz = g_match_info_fetch_named(match_info, "offset");
-                year = g_match_info_fetch_named(match_info, "y");
-                month = g_match_info_fetch_named(match_info, "m");
-                day = g_match_info_fetch_named(match_info, "d");
-                hour = g_match_info_fetch_named(match_info, "H");
-                minute = g_match_info_fetch_named(match_info, "M");
-                seconds = g_match_info_fetch_named(match_info, "s");
-                GDateTime *dateTime;
-                dateTime = dateFromString(tz,
-                                          year,
-                                          month,
-                                          day,
-                                          hour,
-                                          minute,
-                                          seconds);
-                g_free(tz);
-                g_free(year);
-                g_free(month);
-                g_free(day);
-                g_free(hour);
-                g_free(minute);
-                g_free(seconds);
+                GTimeVal dateTime = {0, 0};
+                gchar *date;
+                date = g_match_info_fetch_named(match_info, "date");
+                g_warn_if_fail(RFC1123StrToTime(date, dateTime.tv_sec));
+                g_free(date);
 
-                issued = g_date_time_format(dateTime, "%FT%R:%S");
+                issued = g_time_val_to_iso8601(&dateTime);
                 if (updated.empty()) {
-                    updated = g_date_time_format(dateTime, "%FT%R:%S");
+                    updated = g_time_val_to_iso8601(&dateTime);
                 }
             }
             g_match_info_free(match_info);
@@ -1291,20 +1289,76 @@ void aptcc::updateInterface(int fd, int writeFd)
 					new_file.append(1, str[i]);
 				i++;
 
-				gchar *confmsg;
-				confmsg = g_strdup_printf("The configuration file '%s' "
-							  "(modified by you or a script) "
-							  "has a newer version '%s'.\n"
-							  "Please verify your changes and update it manually.",
-							  orig_file.c_str(),
-							  new_file.c_str());
-				pk_backend_message(m_backend,
-						   PK_MESSAGE_ENUM_CONFIG_FILES_CHANGED,
-						   confmsg);
-				if (write(writeFd, "N\n", 2) != 2) {
-					// TODO we need a DPKG patch to use debconf
-					g_debug("Failed to write");
-				}
+                gchar *filename;
+                filename = g_build_filename(DATADIR, "PackageKit", "helpers", "aptcc", "pkconffile", NULL);
+                gint exit_code;
+                gchar **argv;
+                gchar **envp;
+                GError *error = NULL;
+                argv = (gchar **) g_malloc(5 * sizeof(gchar *));
+                argv[0] = filename;
+                argv[1] = g_strdup(m_lastPackage.c_str());
+                argv[2] = g_strdup(orig_file.c_str());
+                argv[3] = g_strdup(new_file.c_str());
+                argv[4] = NULL;
+
+                gchar *socket;
+                if (socket = pk_backend_get_frontend_socket(m_backend)) {
+                    envp = (gchar **) g_malloc(3 * sizeof(gchar *));
+                    envp[0] = g_strdup("DEBIAN_FRONTEND=passthrough");
+                    envp[1] = g_strdup_printf("DEBCONF_PIPE=%s", socket);
+                    envp[2] = NULL;
+                } else {
+                    // we don't have a socket set, let's fallback to noninteractive
+                    envp = (gchar **) g_malloc(2 * sizeof(gchar *));
+                    envp[0] = g_strdup("DEBIAN_FRONTEND=noninteractive");
+                    envp[1] = NULL;
+                }
+
+                gboolean ret;
+                ret = g_spawn_sync(NULL, // working dir
+                             argv, // argv
+                             envp, // envp
+                             G_SPAWN_LEAVE_DESCRIPTORS_OPEN,
+                             NULL, // child_setup
+                             NULL, // user_data
+                             NULL, // standard_output
+                             NULL, // standard_error
+                             &exit_code,
+                             &error);
+
+                cout << filename << " " << exit_code << " ret: "<< ret << endl;
+
+                if (exit_code == 10) {
+                    // 1 means the user wants the package config
+                    if (write(writeFd, "Y\n", 2) != 2) {
+                        // TODO we need a DPKG patch to use debconf
+                        g_debug("Failed to write");
+                    }
+                } else if (exit_code == 20) {
+                    // 2 means the user wants to keep the current config
+                    if (write(writeFd, "N\n", 2) != 2) {
+                        // TODO we need a DPKG patch to use debconf
+                        g_debug("Failed to write");
+                    }
+                } else {
+                    // either the user didn't choose an option or the front end failed'
+                    gchar *confmsg;
+                    confmsg = g_strdup_printf("The configuration file '%s' "
+                                "(modified by you or a script) "
+                                "has a newer version '%s'.\n"
+                                "Please verify your changes and update it manually.",
+                                orig_file.c_str(),
+                                new_file.c_str());
+                    pk_backend_message(m_backend,
+                                       PK_MESSAGE_ENUM_CONFIG_FILES_CHANGED,
+                                       confmsg);
+                    // fall back to keep the current config file
+                    if (write(writeFd, "N\n", 2) != 2) {
+                        // TODO we need a DPKG patch to use debconf
+                        g_debug("Failed to write");
+                    }
+                }
 			} else if (strstr(status, "pmstatus") != NULL) {
 				// INSTALL & UPDATE
 				// - Running dpkg
@@ -1787,30 +1841,22 @@ cout << "How odd.. The sizes didn't match, email apt@packages.debian.org";
 
 	// File descriptors for reading dpkg --status-fd
 	int readFromChildFD[2];
-	int writeToChildFD[2];
-	if (pipe(readFromChildFD) < 0 || pipe(writeToChildFD) < 0) {
+	if (pipe(readFromChildFD) < 0) {
 		cout << "Failed to create a pipe" << endl;
 		return false;
 	}
 
-	m_child_pid = fork();
+	int pty_master;
+	m_child_pid = forkpty(&pty_master, NULL, NULL, NULL);
 	if (m_child_pid == -1) {
 		return false;
 	}
 
 	if (m_child_pid == 0) {
-		close(0);
 		//cout << "FORKED: installPackages(): DoInstall" << endl;
-		// redirect writeToChildFD to stdin
-		if (dup(writeToChildFD[0]) != 0) {
-			cerr << "Aptcc: dup failed duplicate pipe to stdin" << endl;
-			close(readFromChildFD[1]);
-			close(writeToChildFD[0]);
-			_exit(1);
-		}
 
-		// close Forked stdout and the read end of the pipe
-		close(1);
+		// close pipe we don't need
+		close(readFromChildFD[0]);
 
 		// Change the locale to not get libapt localization
 		setlocale(LC_ALL, "C");
@@ -1839,10 +1885,7 @@ cout << "How odd.. The sizes didn't match, email apt@packages.debian.org";
 		// dump errors into cerr (pass it to the parent process)
 		_error->DumpErrors();
 
-		close(readFromChildFD[0]);
-		close(writeToChildFD[1]);
 		close(readFromChildFD[1]);
-		close(writeToChildFD[0]);
 
 		_exit(res);
 	}
@@ -1859,13 +1902,12 @@ cout << "How odd.. The sizes didn't match, email apt@packages.debian.org";
 	// Check if the child died
 	int ret;
 	while (waitpid(m_child_pid, &ret, WNOHANG) == 0) {
-		updateInterface(readFromChildFD[0], writeToChildFD[1]);
+		updateInterface(readFromChildFD[0], pty_master);
 	}
 
 	close(readFromChildFD[0]);
 	close(readFromChildFD[1]);
-	close(writeToChildFD[0]);
-	close(writeToChildFD[1]);
+	close(pty_master);
 
 	cout << "Parent finished..." << endl;
 	return true;
