@@ -73,6 +73,9 @@ pk_backend_initialize (PkBackend *backend)
 		g_debug ("ERROR initializing backend");
 	}
 
+    // Disable apt-listbugs as it freezes PK
+    setenv("APT_LISTBUGS_FRONTEND", "none", 1);
+
 	spawn = pk_backend_spawn_new ();
 	pk_backend_spawn_set_name (spawn, "aptcc");
 }
@@ -194,8 +197,9 @@ backend_get_depends_or_requires_thread (PkBackend *backend)
 		}
 
 		pair<pkgCache::PkgIterator, pkgCache::VerIterator> pkg_ver;
-		pkg_ver = m_apt->find_package_id(pi);
-		if (pkg_ver.second.end() == true)
+        bool found;
+		pkg_ver = m_apt->find_package_id(pi, found);
+		if (!found)
 		{
 			pk_backend_error_code (backend,
 					       PK_ERROR_ENUM_PACKAGE_NOT_FOUND,
@@ -288,8 +292,9 @@ backend_get_files_thread (PkBackend *backend)
 		}
 
 		pair<pkgCache::PkgIterator, pkgCache::VerIterator> pkg_ver;
-		pkg_ver = m_apt->find_package_id(pi);
-		if (pkg_ver.second.end() == true)
+        bool found;
+		pkg_ver = m_apt->find_package_id(pi, found);
+		if (!found)
 		{
 			pk_backend_error_code (backend, PK_ERROR_ENUM_PACKAGE_NOT_FOUND, "Couldn't find package");
 			delete m_apt;
@@ -358,8 +363,9 @@ backend_get_details_thread (PkBackend *backend)
 		}
 
 		pair<pkgCache::PkgIterator, pkgCache::VerIterator> pkg_ver;
-		pkg_ver = m_apt->find_package_id(pi);
-		if (pkg_ver.second.end() == true)
+        bool found;
+		pkg_ver = m_apt->find_package_id(pi, found);
+		if (!found)
 		{
 			pk_backend_error_code (backend,
 					       PK_ERROR_ENUM_PACKAGE_NOT_FOUND,
@@ -371,9 +377,9 @@ backend_get_details_thread (PkBackend *backend)
 		}
 
 		if (updateDetail) {
-			m_apt->emit_update_detail(pkg_ver.first);
+			m_apt->emit_update_detail(pkg_ver.first, pkg_ver.second);
 		} else {
-			m_apt->emit_details(pkg_ver.first);
+			m_apt->emit_details(pkg_ver.first, pkg_ver.second);
 		}
 	}
 
@@ -672,9 +678,10 @@ pk_backend_download_packages_thread (PkBackend *backend)
 		}
 
 		pair<pkgCache::PkgIterator, pkgCache::VerIterator> pkg_ver;
-		pkg_ver = m_apt->find_package_id(pi);
+        bool found;
+		pkg_ver = m_apt->find_package_id(pi, found);
 		// Ignore packages that could not be found or that exist only due to dependencies.
-		if (pkg_ver.second.end() == true)
+		if (!found)
 		{
 			_error->Error("Can't find this package id \"%s\".", pi);
 			continue;
@@ -854,9 +861,10 @@ pk_backend_resolve_thread (PkBackend *backend)
 				output.push_back(pkg_ver);
 			}
 		} else {
-			pkg_ver = m_apt->find_package_id(pi);
+            bool found;
+			pkg_ver = m_apt->find_package_id(pi, found);
 			// check to see if we found the package
-			if (pkg_ver.second.end() == false)
+			if (found)
 			{
 				output.push_back(pkg_ver);
 			}
@@ -988,7 +996,7 @@ backend_search_groups_thread (PkBackend *backend)
 		// Ignore virtual packages
 		pkgCache::VerIterator ver = m_apt->find_ver(pkg);
 		if (ver.end() == false) {
-			string section = pkg.VersionList().Section();
+			string section = pkg.VersionList().Section() == NULL ? "" : pkg.VersionList().Section();
 
 			size_t found;
 			found = section.find_last_of("/");
@@ -1079,52 +1087,30 @@ backend_search_package_thread (PkBackend *backend)
 				continue;
 			}
 
-			pkgCache::VerIterator ver = m_apt->find_ver(pkg);
-			if (m_matcher->matches(pkg.Name())) {
-				// Don't insert virtual packages instead add what it provides
-				if (ver.end() == false) {
-					output.push_back(pair<pkgCache::PkgIterator, pkgCache::VerIterator>(pkg, ver));
-				} else {
-					// iterate over the provides list
-					for (pkgCache::PrvIterator Prv = pkg.ProvidesList(); Prv.end() == false; Prv++) {
-						ver = m_apt->find_ver(Prv.OwnerPkg());
+            pkgCache::VerIterator ver = m_apt->find_ver(pkg);
+            if (ver.end() == false) {
+                if (m_matcher->matches(pkg.Name()) ||
+                    m_matcher->matches(get_long_description(ver, m_apt->packageRecords))) {
+                    // The package matched
+                    output.push_back(pair<pkgCache::PkgIterator, pkgCache::VerIterator>(pkg, ver));
+                }
+            } else if (m_matcher->matches(pkg.Name())) {
+                // The package is virtual and MATCHED the name
+                // Don't insert virtual packages instead add what it provides
 
-						// check to see if the provided package isn't virtual too
-						if (ver.end() == false)
-						{
-							// we add the package now because we will need to
-							// remove duplicates later anyway
-							output.push_back(pair<pkgCache::PkgIterator, pkgCache::VerIterator>(Prv.OwnerPkg(), ver));
-						}
-					}
-				}
-			} else {
-				// Don't insert virtual packages instead add what it provides
-				if (ver.end() == false) {
-					if (m_matcher->matches(get_short_description(ver, m_apt->packageRecords))
-					 || m_matcher->matches(get_long_description(ver, m_apt->packageRecords)))
-					{
-						output.push_back(pair<pkgCache::PkgIterator, pkgCache::VerIterator>(pkg, ver));
-					}
-				} else {
-					// iterate over the provides list
-					for (pkgCache::PrvIterator Prv = pkg.ProvidesList(); Prv.end() == false; Prv++) {
-						ver = m_apt->find_ver(Prv.OwnerPkg());
+                // iterate over the provides list
+                for (pkgCache::PrvIterator Prv = pkg.ProvidesList(); Prv.end() == false; Prv++) {
+                        ver = m_apt->find_ver(Prv.OwnerPkg());
 
-						// check to see if the provided package isn't virtual too
-						if (ver.end() == false)
-						{
-							// we add the package now because we will need to
-							// remove duplicates later anyway
-							if (m_matcher->matches(get_short_description(ver, m_apt->packageRecords))
-							 || m_matcher->matches(get_long_description(ver, m_apt->packageRecords)))
-							{
-								output.push_back(pair<pkgCache::PkgIterator, pkgCache::VerIterator>(Prv.OwnerPkg(), ver));
-							}
-						}
-					}
-				}
-			}
+                    // check to see if the provided package isn't virtual too
+                    if (ver.end() == false)
+                    {
+                        // we add the package now because we will need to
+                        // remove duplicates later anyway
+                        output.push_back(pair<pkgCache::PkgIterator, pkgCache::VerIterator>(Prv.OwnerPkg(), ver));
+                    }
+                }
+            }
 		}
 	} else {
 		for (pkgCache::PkgIterator pkg = m_apt->packageCache->PkgBegin(); !pkg.end(); ++pkg) {
@@ -1231,9 +1217,10 @@ backend_manage_packages_thread (PkBackend *backend)
 		}
 
 		pair<pkgCache::PkgIterator, pkgCache::VerIterator> pkg_ver;
-		pkg_ver = m_apt->find_package_id(pi);
+        bool found;
+		pkg_ver = m_apt->find_package_id(pi, found);
 		// Ignore packages that could not be found or that exist only due to dependencies.
-		if (pkg_ver.second.end() == true)
+		if (!found)
 		{
 			pk_backend_error_code (backend,
 					       PK_ERROR_ENUM_PACKAGE_NOT_FOUND,
