@@ -65,13 +65,19 @@ from entropy.core.settings.base import SystemSettings
 from entropy.misc import LogFile
 from entropy.cache import EntropyCacher
 from entropy.exceptions import SystemDatabaseError
+from entropy.db.exceptions import Error as EntropyRepositoryError
 try:
     from entropy.exceptions import DependenciesNotRemovable
 except ImportError:
     DependenciesNotRemovable = Exception
 from entropy.fetchers import UrlFetcher
+try:
+    from entropy.services.client import WebService
+except ImportError:
+    WebService = None
 
 import entropy.tools
+import entropy.dep
 
 PK_DEBUG = False
 
@@ -347,25 +353,50 @@ class PackageKitEntropyMixin(object):
         Return repository name (identifier) given an EntropyRepository
         instance.
         """
+        if hasattr(repo_db, "name"):
+            # new Entropy releases, >=1.0_alpha8
+            return repo_db.name
         repo_name = self._repo_name_cache.get(repo_db)
         if repo_name is None:
             repo_name = repo_db.get_plugins_metadata().get("repo_name")
             self._repo_name_cache[repo_db] = repo_name
         return repo_name
 
+    def _etp_get_webservice(self, repository_id):
+        """
+        Get Entropy Web Services service object (ClientWebService).
+
+        @param entropy_client: Entropy Client interface
+        @type entropy_client: entropy.client.interfaces.Client
+        @param repository_id: repository identifier
+        @type repository_id: string
+        @return: the ClientWebService instance
+        @rtype: entropy.client.services.interfaces.ClientWebService
+        @raise WebService.UnsupportedService: if service is unsupported by
+            repository
+        """
+        factory = self._entropy.WebServices()
+        return factory.new(repository_id)
+
     def _etp_spawn_ugc(self, pkg_data):
         """
         Inform repository maintainers that user fetched packages, if user
         enabled this feature.
         """
-        if self._entropy.UGC is None:
+        if WebService is None:
+            # old entropy library, ignore all
             return
-        for repo_id in pkg_data:
-            repo_pkg_keys = sorted(pkg_data[repo_id])
+
+        for repository_id, repo_pkg_keys in pkg_data.items():
             try:
-                self._entropy.UGC.add_download_stats(repo_id, repo_pkg_keys)
-            except:
-                pass
+                webserv = self._etp_get_webservice(repository_id)
+            except WebService.UnsupportedService:
+                continue
+            pkg_keys = sorted(repo_pkg_keys)
+            try:
+                webserv.add_downloads(pkg_keys)
+            except WebService.WebServiceException:
+                continue
 
     def _etp_get_category_description(self, category):
         """
@@ -417,7 +448,7 @@ class PackageKitEntropyMixin(object):
         for pkg_id, c_repo, pk_pkg in pkgs:
             if c_repo is not self._entropy.installed_repository():
                 self.error(ERROR_DEP_RESOLUTION_FAILED,
-                    "Cannot remove a package coming fro a repository: %s" % (
+                    "Cannot remove a package coming from a repository: %s" % (
                         pk_pkg,))
                 return
 
@@ -448,6 +479,11 @@ class PackageKitEntropyMixin(object):
 
         self.percentage(0)
         self.status(STATUS_REMOVE)
+        inst_repo = self._entropy.installed_repository()
+
+        def _generate_map_item(etp_pkg_id):
+            _etp_match = (etp_pkg_id, inst_repo)
+            return etp_pkg_id, inst_repo, self._etp_to_id(_etp_match)
 
         # remove
         max_count = len(run_queue)
@@ -457,11 +493,15 @@ class PackageKitEntropyMixin(object):
 
             percent = PackageKitEntropyMixin.get_percentage(count, max_count)
 
-            self._log_message(__name__, "get_packages: done %s/100" % (
-                percent,))
+            self._log_message(__name__,
+                "_execute_etp_pkgs_remove: done %s/100" % (
+                    percent,))
 
             self.percentage(percent)
-            pkg_id, pkg_c_repo, pk_pkg = match_map.get(pkg_id)
+            map_item = match_map.get(pkg_id)
+            if map_item is None:
+                map_item = _generate_map_item(pkg_id)
+            pkg_id, pkg_c_repo, pk_pkg = map_item
             pkg_desc = pkg_c_repo.retrieveDescription(pkg_id)
             self.package(pk_pkg, INFO_REMOVING, pkg_desc)
 
@@ -615,7 +655,7 @@ class PackageKitEntropyMixin(object):
             package.prepare(match, "fetch", metaopts)
             myrepo = package.pkgmeta['repository']
             obj = down_data.setdefault(myrepo, set())
-            obj.add(entropy.tools.dep_getkey(package.pkgmeta['atom']))
+            obj.add(entropy.dep.dep_getkey(package.pkgmeta['atom']))
 
             x_rc = package.run()
             if x_rc != 0:
@@ -689,6 +729,8 @@ class PackageKitEntropyClient(Client):
 
     _pk_progress = None
     _pk_message = None
+    def init_singleton(self):
+        Client.init_singleton(self, url_fetcher = PkUrlFetcher)
 
     def output(self, text, header = "", footer = "", back = False,
         importance = 0, level = "info", count = None, percent = False):
@@ -794,7 +836,6 @@ class PackageKitEntropyBackend(PackageKitBaseBackend, PackageKitEntropyMixin):
         self.doLock()
         signal.signal(signal.SIGQUIT, self.__sigquit)
         PkUrlFetcher._pk_progress = self.sub_percentage
-        self._entropy.urlFetcher = PkUrlFetcher
         self._repo_name_cache = {}
         PackageKitEntropyClient._pk_progress = self.percentage
         PackageKitEntropyClient._pk_message = self._generic_message
@@ -821,7 +862,7 @@ class PackageKitEntropyBackend(PackageKitBaseBackend, PackageKitEntropyMixin):
         self._log_message(__name__, "_generic_message:", decolorize(message))
 
     def _config_files_message(self):
-        scandata = self._entropy.FileUpdates.scan(dcache = True,
+        scandata = self._entropy.PackageFileUpdates().scan(dcache = True,
             quiet = True)
         if scandata is None:
             return
@@ -943,6 +984,17 @@ class PackageKitEntropyBackend(PackageKitBaseBackend, PackageKitEntropyMixin):
 
         self.percentage(100)
 
+    def _etp_get_package_categories(self):
+        categories = set()
+        for repository_id in self._entropy.repositories():
+            repo_db = self._entropy.open_repository(repository_id)
+            try:
+                categories.update(repo_db.listAllCategories())
+            except EntropyRepositoryError:
+                # on broken repos this might cause issues
+                continue
+        return sorted(categories)
+
     def get_categories(self):
 
         self._log_message(__name__, "get_categories: called")
@@ -950,7 +1002,7 @@ class PackageKitEntropyBackend(PackageKitBaseBackend, PackageKitEntropyMixin):
         self.status(STATUS_QUERY)
         self.allow_cancel(True)
 
-        categories = self._entropy.get_package_categories()
+        categories = self._etp_get_package_categories()
         if not categories:
             self.error(ERROR_GROUP_LIST_INVALID, "no package categories")
             return
@@ -1117,7 +1169,7 @@ class PackageKitEntropyBackend(PackageKitBaseBackend, PackageKitEntropyMixin):
 
         empty = False
         deep = False
-        reverse_deps = self._entropy.get_reverse_dependencies(matches,
+        reverse_deps = self._entropy.get_reverse_queue(matches,
             deep = deep, recursive = recursive)
 
         self._log_message(__name__, "get_requires: reverse_deps => %s" % (
@@ -1168,8 +1220,8 @@ class PackageKitEntropyBackend(PackageKitBaseBackend, PackageKitEntropyMixin):
 
             updates = []
             keyslot = c_repo.retrieveKeySlotAggregated(pkg_id)
-            matches, m_rc = self._entropy.atom_match(keyslot, multiMatch = True,
-                multiRepo = True)
+            matches, m_rc = self._entropy.atom_match(keyslot, multi_match = True,
+                multi_repo = True)
             for m_pkg_id, m_repo_id in matches:
                 if (m_pkg_id, m_repo_id) == (pkg_id, repo_name):
                     continue # fliter myself
@@ -1281,7 +1333,8 @@ class PackageKitEntropyBackend(PackageKitBaseBackend, PackageKitEntropyMixin):
         pkg_ids = []
         for etp_file in inst_files:
             repo_id = os.path.basename(etp_file)
-            status, atomsfound = self._entropy.add_package_to_repos(etp_file)
+            status, atomsfound = self._entropy.add_package_to_repositories(
+                etp_file)
             if status != 0:
                 self.error(ERROR_INVALID_PACKAGE_FILE,
                     "Error while trying to add %s repository" % (repo_id,))
@@ -1349,6 +1402,24 @@ class PackageKitEntropyBackend(PackageKitBaseBackend, PackageKitEntropyMixin):
 
         self._execute_etp_pkgs_fetch(pkgs, directory)
 
+    def _etp_update_repository_stats(self, repository_ids):
+        """
+        Update repository download statistics.
+        """
+        if WebService is None:
+            # old entropy library, ignore all
+            return
+
+        for repository_id in repository_ids:
+            try:
+                webserv = self._etp_get_webservice(repository_id)
+            except WebService.UnsupportedService:
+                continue
+            try:
+                webserv.add_downloads(repository_id, [repository_id])
+            except WebService.WebServiceException:
+                continue
+
     def refresh_cache(self, force):
 
         self.status(STATUS_REFRESH_CACHE)
@@ -1370,10 +1441,7 @@ class PackageKitEntropyBackend(PackageKitBaseBackend, PackageKitEntropyMixin):
 
         ex_rc = repo_intf.sync()
         if not ex_rc:
-            for repo_id in repo_identifiers:
-                # inform UGC that we are syncing this repo
-                if self._entropy.UGC is not None:
-                    self._entropy.UGC.add_download_stats(repo_id, [repo_id])
+            self._etp_update_repository_stats(repo_identifiers)
         else:
             self.message(MESSAGE_REPO_METADATA_DOWNLOAD_FAILED,
                 "Cannot update repositories!")
