@@ -16,16 +16,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <gmodule.h>
 #include <glib.h>
 #include <string.h>
-#include <packagekit-glib/packagekit.h>
 #include <pk-backend.h>
 #include <pk-backend-internal.h>
-#include <egg-debug.h>
 
 #include <razor/razor.h>
 
@@ -122,7 +120,7 @@ backend_resolve_thread (PkBackend *backend)
 					    RAZOR_DETAIL_SUMMARY, &summary,
 					    RAZOR_DETAIL_LAST)) {
 		for (i=0; i<length; i++) {
-			if (egg_strequal (name, package_ids[i])) {
+			if (g_strcmp0 (name, package_ids[i]) == 0) {
 				pk_razor_emit_package (backend, name, version, arch, summary);
 			}
 		}
@@ -171,7 +169,7 @@ backend_get_details_thread (PkBackend *backend)
 		for (i=0; i<length; i++) {
 			/* TODO: we should cache this */
 			id = pk_package_id_new_from_string (package_ids[i]);
-			if (egg_strequal (name, id->name)) {
+			if (g_strcmp0 (name, id->name) == 0) {
 				package_id = pk_package_id_build (name, version, arch, "installed");
 				razor_package_get_details (set, package,
 							   RAZOR_DETAIL_SUMMARY, &summary,
@@ -216,7 +214,7 @@ backend_resolve_package_id (const PkPackageId *id)
 					    RAZOR_DETAIL_VERSION, &version,
 					    RAZOR_DETAIL_ARCH, &arch,
 					    RAZOR_DETAIL_LAST)) {
-		if (egg_strequal (name, id->name)) {
+		if (g_strcmp0 (name, id->name) == 0) {
 			package_retval = package;
 			break;
 		}
@@ -392,6 +390,7 @@ backend_get_filters (PkBackend *backend)
 	return pk_bitfield_from_enums (PK_FILTER_ENUM_DEVELOPMENT, -1);
 }
 
+/* FIXME: port this away from PK_BACKEND_OPTIONS */
 PK_BACKEND_OPTIONS (
 	"razor",				/* description */
 	"Richard Hughes <richard@hughsie.com>",	/* author */
@@ -399,6 +398,7 @@ PK_BACKEND_OPTIONS (
 	backend_destroy,			/* destroy */
 	NULL,					/* get_groups */
 	backend_get_filters,			/* get_filters */
+	NULL,					/* get_roles */
 	NULL,					/* get_mime_types */
 	NULL,					/* cancel */
 	NULL,					/* download_packages */
@@ -427,6 +427,13 @@ PK_BACKEND_OPTIONS (
 	backend_search_name,			/* search_name */
 	NULL,					/* update_packages */
 	NULL,					/* update_system */
-	NULL					/* what_provides */
+	NULL,					/* what_provides */
+	NULL,					/* simulate_install_files */
+	NULL,					/* simulate_install_packages */
+	NULL,					/* simulate_remove_packages */
+	NULL,					/* simulate_update_packages */
+	NULL,					/* upgrade_system */
+	NULL,					/* transaction_start */
+	NULL					/* transaction_stop */
 );
 
