@@ -28,6 +28,7 @@ from packagekit.package import PackagekitPackage
 from packagekit.enums import *
 import re
 import sys
+import os
 import codecs
 import locale
 
@@ -938,7 +939,6 @@ class PackageKitSmartBackend(PackageKitBaseBackend):
     systemchannel = None # unfortunately package strings depend on system
 
     def _machine(self):
-        import os
         machine = os.uname()[-1]
         if machine == "Power Macintosh": #<sigh>
             machine = "ppc"
@@ -1029,7 +1029,7 @@ class PackageKitSmartBackend(PackageKitBaseBackend):
         if repoid == 'local':
             channels = self.ctrl.getFileChannels()
         elif repoid:
-            if repoid == 'installed':
+            if repoid.startswith('installed'):
                 repoid = self.systemchannel
             channels = self.ctrl.getChannels()
             channels = [x for x in channels if x.getAlias() == repoid]
@@ -1073,6 +1073,10 @@ class PackageKitSmartBackend(PackageKitBaseBackend):
         channel = loader.getChannel()
         if package.installed:
             data = 'installed'
+            if hasattr(smart.pkgconf, 'getOrigin'):
+                origin = smart.pkgconf.getOrigin(package)
+                if origin:
+                    data += ':' + origin
         elif self._channel_is_local(channel):
             data = 'local'
         else:
@@ -1330,5 +1334,11 @@ def main():
     backend = PackageKitSmartBackend('')
     backend.dispatcher(sys.argv[1:])
 
+# Required for daemon mode
+if sys.platform.startswith("linux"):
+    os.putenv("PATH", "/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin")
+elif sys.platform.startswith("freebsd"):
+    os.putenv("PATH", "/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin")
+
 if __name__ == "__main__":
     main()
