@@ -31,7 +31,7 @@ static PkBackendSpawn *spawn;
 static void
 backend_initialize (PkBackend *backend)
 {
-	egg_debug ("backend: initialize");
+	g_debug ("backend: initialize");
 	spawn = pk_backend_spawn_new ();
 	pk_backend_spawn_set_name (spawn, "urpmi");
 }
@@ -43,7 +43,7 @@ backend_initialize (PkBackend *backend)
 static void
 backend_destroy (PkBackend *backend)
 {
-	egg_debug ("backend: destroy");
+	g_debug ("backend: destroy");
 	g_object_unref (spawn);
 }
 
@@ -359,7 +359,7 @@ backend_get_distro_upgrades (PkBackend *backend)
 	pk_backend_spawn_helper (spawn, "urpmi-dispatched-backend.pl", "get-distro-upgrades", NULL);
 }
 
-
+/* FIXME: port this away from PK_BACKEND_OPTIONS */
 PK_BACKEND_OPTIONS (
 	"URPMI",					/* description */
 	"Aurelien Lefebvre <alkh@mandriva.org>",	/* author */
@@ -400,6 +400,9 @@ PK_BACKEND_OPTIONS (
 	NULL,					/* simulate_install_files */
 	NULL,					/* simulate_install_packages */
 	NULL,					/* simulate_remove_packages */
-	NULL					/* simulate_update_packages */
+	NULL,					/* simulate_update_packages */
+	NULL,					/* upgrade_system */
+	NULL,					/* transaction_start */
+	NULL					/* transaction_stop */
 );
 
