@@ -209,17 +209,21 @@ pk_main_create_window (PkPlugin *plugin)
 	if (gdk_window == NULL) {
 		GdkWindowAttr attr;
 		GdkWindow *parent;
-		GdkDisplay *gdk_display;
+		GdkDisplay *display;
 
 		// TODO - is it correct? Do we want to translate xdisplay -> GdkDisplay?
-		gdk_display = gdk_display_get_default ();
-		if (gdk_display == NULL) {
+		display = gdk_display_get_default ();
+		if (display == NULL) {
 			pk_debug ("invalid display returned by gdk_display_get_default ()\n");
 			return;
 		}
 
 		/* get parent */
-		parent = gdk_window_foreign_new_for_display (gdk_display, xwindow);
+#if GTK_CHECK_VERSION(2,24,0)
+		parent = gdk_x11_window_foreign_new_for_display (display, xwindow);
+#else
+		parent = gdk_window_foreign_new (xwindow);
+#endif
 		if (parent == NULL) {
 			pk_debug ("invalid window given for setup (id %lu)\n", xwindow);
 			return;
