@@ -170,7 +170,6 @@ pk_control_cancellable_cancel_cb (GCancellable *cancellable, PkControlState *sta
 	if (state->call != NULL) {
 		dbus_g_proxy_cancel_call (state->control->priv->proxy, state->call);
 		dbus_g_proxy_cancel_call (state->control->priv->proxy_props, state->call);
-		g_debug ("cancelling, ended DBus call: %p (%p)", state, state->call);
 		state->call = NULL;
 	}
 }
@@ -192,10 +191,6 @@ pk_control_get_tid_state_finish (PkControlState *state, const GError *error)
 
 	/* remove from list */
 	g_ptr_array_remove (state->control->priv->calls, state);
-	if (state->call != NULL)
-		g_warning ("state array remove %p (%p)", state, state->call);
-	else
-		g_debug ("state array remove %p", state);
 
 	/* complete */
 	g_simple_async_result_complete_in_idle (state->res);
@@ -305,7 +300,6 @@ pk_control_get_tid_async (PkControl *control, GCancellable *cancellable, GAsyncR
 
 	/* track state */
 	g_ptr_array_add (control->priv->calls, state);
-	g_debug ("state array add %p (%p)", state, state->call);
 out:
 	g_object_unref (res);
 }
@@ -360,10 +354,6 @@ pk_control_suggest_daemon_quit_state_finish (PkControlState *state, const GError
 
 	/* remove from list */
 	g_ptr_array_remove (state->control->priv->calls, state);
-	if (state->call != NULL)
-		g_warning ("state array remove %p (%p)", state, state->call);
-	else
-		g_debug ("state array remove %p", state);
 
 	/* complete */
 	g_simple_async_result_complete_in_idle (state->res);
@@ -459,7 +449,6 @@ pk_control_suggest_daemon_quit_async (PkControl *control, GCancellable *cancella
 
 	/* track state */
 	g_ptr_array_add (control->priv->calls, state);
-	g_debug ("state array add %p (%p)", state, state->call);
 out:
 	g_object_unref (res);
 }
@@ -514,10 +503,6 @@ pk_control_get_daemon_state_state_finish (PkControlState *state, const GError *e
 
 	/* remove from list */
 	g_ptr_array_remove (state->control->priv->calls, state);
-	if (state->call != NULL)
-		g_warning ("state array remove %p (%p)", state, state->call);
-	else
-		g_debug ("state array remove %p", state);
 
 	/* complete */
 	g_simple_async_result_complete_in_idle (state->res);
@@ -617,7 +602,6 @@ pk_control_get_daemon_state_async (PkControl *control, GCancellable *cancellable
 
 	/* track state */
 	g_ptr_array_add (control->priv->calls, state);
-	g_debug ("state array add %p (%p)", state, state->call);
 out:
 	g_object_unref (res);
 }
@@ -672,10 +656,6 @@ pk_control_set_proxy_state_finish (PkControlState *state, const GError *error)
 
 	/* remove from list */
 	g_ptr_array_remove (state->control->priv->calls, state);
-	if (state->call != NULL)
-		g_warning ("state array remove %p (%p)", state, state->call);
-	else
-		g_debug ("state array remove %p", state);
 
 	/* complete */
 	g_simple_async_result_complete_in_idle (state->res);
@@ -723,21 +703,33 @@ out:
 }
 
 /**
- * pk_control_set_proxy_async:
+ * pk_control_set_proxy2_async:
  * @control: a valid #PkControl instance
- * @proxy_http: a HTTP proxy string such as "username:password@server.lan:8080"
- * @proxy_ftp: a FTP proxy string such as "server.lan:8080"
+ * @proxy_http: a HTTP proxy string such as "username:password@server.lan:8080", or %NULL
+ * @proxy_https: a HTTPS proxy string such as "username:password@server.lan:8080", or %NULL
+ * @proxy_ftp: a FTP proxy string such as "server.lan:8080", or %NULL
+ * @proxy_socks: a SOCKS proxy string such as "server.lan:8080", or %NULL
+ * @no_proxy: a list of download IPs that shouldn't go through the proxy, or %NULL
+ * @pac: a PAC string, or %NULL
  * @cancellable: a #GCancellable or %NULL
  * @callback: the function to run on completion
  * @user_data: the data to pass to @callback
  *
  * Set a proxy on the PK daemon
  *
- * Since: 0.5.2
+ * Since: 0.6.13
  **/
 void
-pk_control_set_proxy_async (PkControl *control, const gchar *proxy_http, const gchar *proxy_ftp, GCancellable *cancellable,
-			    GAsyncReadyCallback callback, gpointer user_data)
+pk_control_set_proxy2_async (PkControl *control,
+			     const gchar *proxy_http,
+			     const gchar *proxy_https,
+			     const gchar *proxy_ftp,
+			     const gchar *proxy_socks,
+			     const gchar *no_proxy,
+			     const gchar *pac,
+			     GCancellable *cancellable,
+			     GAsyncReadyCallback callback,
+			     gpointer user_data)
 {
 	GSimpleAsyncResult *res;
 	PkControlState *state;
@@ -769,18 +761,57 @@ pk_control_set_proxy_async (PkControl *control, const gchar *proxy_http, const g
 	state->call = dbus_g_proxy_begin_call (control->priv->proxy, "SetProxy",
 					       (DBusGProxyCallNotify) pk_control_set_proxy_cb, state, NULL,
 					       G_TYPE_STRING, proxy_http,
+					       G_TYPE_STRING, proxy_https,
 					       G_TYPE_STRING, proxy_ftp,
+					       G_TYPE_STRING, proxy_socks,
+					       G_TYPE_STRING, no_proxy,
+					       G_TYPE_STRING, pac,
 					       G_TYPE_INVALID);
 	if (state->call == NULL)
 		g_error ("failed to setup call, maybe OOM or no connection");
 
 	/* track state */
 	g_ptr_array_add (control->priv->calls, state);
-	g_debug ("state array add %p (%p)", state, state->call);
 out:
 	g_object_unref (res);
 }
 
+/**
+ * pk_control_set_proxy_async:
+ * @control: a valid #PkControl instance
+ * @proxy_http: a HTTP proxy string such as "username:password@server.lan:8080"
+ * @proxy_ftp: a FTP proxy string such as "server.lan:8080"
+ * @cancellable: a #GCancellable or %NULL
+ * @callback: the function to run on completion
+ * @user_data: the data to pass to @callback
+ *
+ * Set a proxy on the PK daemon
+ *
+ * NOTE: This is just provided for backwards compatibility.
+ * Clients should really be using pk_control_set_proxy2_async().
+ *
+ * Since: 0.5.2
+ **/
+void
+pk_control_set_proxy_async (PkControl *control,
+			    const gchar *proxy_http,
+			    const gchar *proxy_ftp,
+			    GCancellable *cancellable,
+			    GAsyncReadyCallback callback,
+			    gpointer user_data)
+{
+	pk_control_set_proxy2_async (control,
+				     proxy_http,
+				     NULL,
+				     proxy_ftp,
+				     NULL,
+				     NULL,
+				     NULL,
+				     cancellable,
+				     callback,
+				     user_data);
+}
+
 /**
  * pk_control_set_proxy_finish:
  * @control: a valid #PkControl instance
@@ -831,10 +862,6 @@ pk_control_set_root_state_finish (PkControlState *state, const GError *error)
 
 	/* remove from list */
 	g_ptr_array_remove (state->control->priv->calls, state);
-	if (state->call != NULL)
-		g_warning ("state array remove %p (%p)", state, state->call);
-	else
-		g_debug ("state array remove %p", state);
 
 	/* complete */
 	g_simple_async_result_complete_in_idle (state->res);
@@ -933,7 +960,6 @@ pk_control_set_root_async (PkControl *control, const gchar *root, GCancellable *
 
 	/* track state */
 	g_ptr_array_add (control->priv->calls, state);
-	g_debug ("state array add %p (%p)", state, state->call);
 out:
 	g_object_unref (res);
 }
@@ -988,10 +1014,6 @@ pk_control_get_transaction_list_state_finish (PkControlState *state, const GErro
 
 	/* remove from list */
 	g_ptr_array_remove (state->control->priv->calls, state);
-	if (state->call != NULL)
-		g_warning ("state array remove %p (%p)", state, state->call);
-	else
-		g_debug ("state array remove %p", state);
 
 	/* complete */
 	g_simple_async_result_complete_in_idle (state->res);
@@ -1091,7 +1113,6 @@ pk_control_get_transaction_list_async (PkControl *control, GCancellable *cancell
 
 	/* track state */
 	g_ptr_array_add (control->priv->calls, state);
-	g_debug ("state array add %p (%p)", state, state->call);
 out:
 	g_object_unref (res);
 }
@@ -1146,10 +1167,6 @@ pk_control_get_time_since_action_state_finish (PkControlState *state, const GErr
 
 	/* remove from list */
 	g_ptr_array_remove (state->control->priv->calls, state);
-	if (state->call != NULL)
-		g_warning ("state array remove %p (%p)", state, state->call);
-	else
-		g_debug ("state array remove %p", state);
 
 	/* complete */
 	g_simple_async_result_complete_in_idle (state->res);
@@ -1259,7 +1276,6 @@ pk_control_get_time_since_action_async (PkControl *control, PkRoleEnum role, GCa
 
 	/* track state */
 	g_ptr_array_add (control->priv->calls, state);
-	g_debug ("state array add %p (%p)", state, state->call);
 out:
 	g_object_unref (res);
 }
@@ -1314,10 +1330,6 @@ pk_control_can_authorize_state_finish (PkControlState *state, const GError *erro
 
 	/* remove from list */
 	g_ptr_array_remove (state->control->priv->calls, state);
-	if (state->call != NULL)
-		g_warning ("state array remove %p (%p)", state, state->call);
-	else
-		g_debug ("state array remove %p", state);
 
 	/* complete */
 	g_simple_async_result_complete_in_idle (state->res);
@@ -1427,7 +1439,6 @@ pk_control_can_authorize_async (PkControl *control, const gchar *action_id, GCan
 
 	/* track state */
 	g_ptr_array_add (control->priv->calls, state);
-	g_debug ("state array add %p (%p)", state, state->call);
 out:
 	g_object_unref (res);
 }
@@ -1481,10 +1492,6 @@ pk_control_get_properties_state_finish (PkControlState *state, const GError *err
 
 	/* remove from list */
 	g_ptr_array_remove (state->control->priv->calls, state);
-	if (state->call != NULL)
-		g_warning ("state array remove %p (%p)", state, state->call);
-	else
-		g_debug ("state array remove %p", state);
 
 	/* complete */
 	g_simple_async_result_complete_in_idle (state->res);
@@ -1701,6 +1708,10 @@ pk_control_set_network_state (PkControl *control, PkNetworkEnum network_state)
 static void
 pk_control_set_distro_id (PkControl *control, const gchar *distro_id)
 {
+	/* we don't want distro specific results in 'make check' */
+	if (g_getenv ("PK_SELF_TEST") != NULL)
+		distro_id = "selftest;11.91;i686";
+
 	/* is the same as before */
 	if (g_strcmp0 (control->priv->distro_id, distro_id) == 0)
 		return;
@@ -1841,7 +1852,6 @@ pk_control_get_properties_async (PkControl *control, GCancellable *cancellable,
 
 	/* track state */
 	g_ptr_array_add (control->priv->calls, state);
-	g_debug ("state array add %p (%p)", state, state->call);
 out:
 	g_object_unref (res);
 }
@@ -1903,7 +1913,6 @@ pk_control_idle_signal_store_free (PkIdleSignalStore *store)
 static gboolean
 pk_control_transaction_list_changed_idle_cb (PkIdleSignalStore *store)
 {
-	g_debug ("emit transaction-list-changed");
 	g_signal_emit (store->control, signals[SIGNAL_TRANSACTION_LIST_CHANGED], 0, store->transaction_ids);
 	store->control->priv->transaction_list_changed_id = 0;
 	pk_control_idle_signal_store_free (store);
@@ -1912,6 +1921,8 @@ pk_control_transaction_list_changed_idle_cb (PkIdleSignalStore *store)
 
 /**
  * pk_control_transaction_list_changed_cb:
+ *
+ * @transaction_ids: (array zero-terminated=1)
  */
 static void
 pk_control_transaction_list_changed_cb (DBusGProxy *proxy, gchar **transaction_ids, PkControl *control)
@@ -1921,10 +1932,8 @@ pk_control_transaction_list_changed_cb (DBusGProxy *proxy, gchar **transaction_i
 	g_return_if_fail (PK_IS_CONTROL (control));
 
 	/* already pending */
-	if (control->priv->transaction_list_changed_id != 0) {
-		g_debug ("already pending, so ignoring");
+	if (control->priv->transaction_list_changed_id != 0)
 		return;
-	}
 
 	/* create store object */
 	store = g_new0 (PkIdleSignalStore, 1);
@@ -1965,10 +1974,8 @@ pk_control_restart_schedule_cb (DBusGProxy *proxy, PkControl *control)
 	g_return_if_fail (PK_IS_CONTROL (control));
 
 	/* already pending */
-	if (control->priv->restart_schedule_id != 0) {
-		g_debug ("already pending, so ignoring");
+	if (control->priv->restart_schedule_id != 0)
 		return;
-	}
 
 	/* create store object */
 	store = g_new0 (PkIdleSignalStore, 1);
@@ -2008,10 +2015,8 @@ pk_control_updates_changed_cb (DBusGProxy *proxy, PkControl *control)
 	g_return_if_fail (PK_IS_CONTROL (control));
 
 	/* already pending */
-	if (control->priv->updates_changed_id != 0) {
-		g_debug ("already pending, so ignoring");
+	if (control->priv->updates_changed_id != 0)
 		return;
-	}
 
 	/* create store object */
 	store = g_new0 (PkIdleSignalStore, 1);
@@ -2051,10 +2056,8 @@ pk_control_repo_list_changed_cb (DBusGProxy *proxy, PkControl *control)
 	g_return_if_fail (PK_IS_CONTROL (control));
 
 	/* already pending */
-	if (control->priv->repo_list_changed_id != 0) {
-		g_debug ("already pending, so ignoring");
+	if (control->priv->repo_list_changed_id != 0)
 		return;
-	}
 
 	/* create store object */
 	store = g_new0 (PkIdleSignalStore, 1);
@@ -2110,10 +2113,8 @@ static void
 pk_control_changed_cb (DBusGProxy *proxy, PkControl *control)
 {
 	/* already getting properties */
-	if (control->priv->call_get_properties != NULL) {
-		g_warning ("already getting properties, will ignore");
+	if (control->priv->call_get_properties != NULL)
 		return;
-	}
 
 	/* call D-Bus get_properties async */
 	g_debug ("properties changed, so getting new list");
@@ -2142,7 +2143,7 @@ pk_control_cancel_all_dbus_methods (PkControl *control)
 		state = g_ptr_array_index (array, i);
 		if (state->call == NULL)
 			continue;
-		g_debug ("cancel in flight call: %p (%p)", state, state->call);
+		g_debug ("cancel in flight call");
 		dbus_g_proxy_cancel_call (control->priv->proxy, state->call);
 	}
 
