@@ -44,6 +44,7 @@ static const PkEnumMatch enum_exit[] = {
 	{PK_EXIT_ENUM_MEDIA_CHANGE_REQUIRED,	"media-change-required"},
 	{PK_EXIT_ENUM_KILLED,			"killed"},
 	{PK_EXIT_ENUM_NEED_UNTRUSTED,		"need-untrusted"},
+	{PK_EXIT_ENUM_CANCELLED_PRIORITY,	"cancelled-priority"},
 	{0, NULL}
 };
 
@@ -194,6 +195,7 @@ static const PkEnumMatch enum_error[] = {
 	{PK_ERROR_ENUM_PROVIDE_TYPE_NOT_SUPPORTED, "provide-type-not-supported"},
 	{PK_ERROR_ENUM_INSTALL_ROOT_INVALID,	"install-root-invalid"},
 	{PK_ERROR_ENUM_CANNOT_FETCH_SOURCES,	"cannot-fetch-sources"},
+	{PK_ERROR_ENUM_CANCELLED_PRIORITY,	"cancelled-priority"},
 	{0, NULL}
 };
 
@@ -330,6 +332,8 @@ static const PkEnumMatch enum_info[] = {
 	{PK_INFO_ENUM_DOWNGRADING,		"downgrading"},
 	{PK_INFO_ENUM_PREPARING,		"preparing"},
 	{PK_INFO_ENUM_DECOMPRESSING,		"decompressing"},
+	{PK_INFO_ENUM_UNTRUSTED,			"untrusted"},
+	{PK_INFO_ENUM_TRUSTED,				"trusted"},
 	{0, NULL}
 };
 
@@ -355,6 +359,7 @@ static const PkEnumMatch enum_provides[] = {
 	{PK_PROVIDES_ENUM_HARDWARE_DRIVER,	"driver"},
 	{PK_PROVIDES_ENUM_FONT,			"font"},
 	{PK_PROVIDES_ENUM_POSTSCRIPT_DRIVER,	"postscript-driver"},
+	{PK_PROVIDES_ENUM_PLASMA_SERVICE,	"plasma-service"},
 	{0, NULL}
 };
 
