@@ -200,6 +200,7 @@ typedef enum {
 	PK_EXIT_ENUM_KILLED, /* when we forced the cancel, but had to SIGKILL */
 	PK_EXIT_ENUM_MEDIA_CHANGE_REQUIRED,
 	PK_EXIT_ENUM_NEED_UNTRUSTED,
+	PK_EXIT_ENUM_CANCELLED_PRIORITY,
 	PK_EXIT_ENUM_LAST
 } PkExitEnum;
 
@@ -364,6 +365,7 @@ typedef enum {
 	PK_ERROR_ENUM_PROVIDE_TYPE_NOT_SUPPORTED,
 	PK_ERROR_ENUM_INSTALL_ROOT_INVALID,
 	PK_ERROR_ENUM_CANNOT_FETCH_SOURCES,
+	PK_ERROR_ENUM_CANCELLED_PRIORITY,
 	PK_ERROR_ENUM_LAST
 } PkErrorEnum;
 
@@ -454,6 +456,8 @@ typedef enum {
 	PK_INFO_ENUM_DOWNGRADING,
 	PK_INFO_ENUM_PREPARING,
 	PK_INFO_ENUM_DECOMPRESSING,
+	PK_INFO_ENUM_UNTRUSTED,
+	PK_INFO_ENUM_TRUSTED,
 	PK_INFO_ENUM_LAST
 } PkInfoEnum;
 
@@ -494,6 +498,7 @@ typedef enum {
 	PK_PROVIDES_ENUM_FONT,
 	PK_PROVIDES_ENUM_HARDWARE_DRIVER,
 	PK_PROVIDES_ENUM_POSTSCRIPT_DRIVER,
+	PK_PROVIDES_ENUM_PLASMA_SERVICE,
 	PK_PROVIDES_ENUM_LAST
 } PkProvidesEnum;
 
