@@ -286,8 +286,11 @@ pk_task_package_filter_cb (PkPackage *package, gpointer user_data)
 	PkInfoEnum info;
 	info = pk_package_get_info (package);
 	if (info == PK_INFO_ENUM_CLEANUP ||
+	    info == PK_INFO_ENUM_UNTRUSTED ||
 	    info == PK_INFO_ENUM_FINISHED)
 		return FALSE;
+	if (g_strcmp0 (pk_package_get_data (package), "local") == 0)
+		return FALSE;
 	return TRUE;
 }
 
@@ -900,6 +903,12 @@ pk_task_ready_cb (GObject *source_object, GAsyncResult *res, PkTaskState *state)
 		goto out;
 	}
 
+	/* just re-run the transaction */
+	if (state->exit_enum == PK_EXIT_ENUM_CANCELLED_PRIORITY) {
+		pk_task_do_async_action (state);
+		goto out;
+	}
+
 	/* we can't handle this, just finish the async method */
 	state->ret = TRUE;
 
@@ -914,7 +923,7 @@ out:
 /**
  * pk_task_install_packages_async:
  * @task: a valid #PkTask instance
- * @package_ids: a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
+ * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope call): the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -969,7 +978,7 @@ pk_task_install_packages_async (PkTask *task, gchar **package_ids, GCancellable
 /**
  * pk_task_update_packages_async:
  * @task: a valid #PkTask instance
- * @package_ids: a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
+ * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope call): the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -1023,7 +1032,7 @@ pk_task_update_packages_async (PkTask *task, gchar **package_ids, GCancellable *
 /**
  * pk_task_remove_packages_async:
  * @task: a valid #PkTask instance
- * @package_ids: a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
+ * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
  * @allow_deps: if other dependant packages are allowed to be removed from the computer
  * @autoremove: if other packages installed at the same time should be tried to remove
  * @cancellable: a #GCancellable or %NULL
@@ -1082,7 +1091,7 @@ pk_task_remove_packages_async (PkTask *task, gchar **package_ids, gboolean allow
 /**
  * pk_task_install_files_async:
  * @task: a valid #PkTask instance
- * @files: a file such as "/home/hughsie/Desktop/hal-devel-0.10.0.rpm"
+ * @files: (array zero-terminated=1): a file such as "/home/hughsie/Desktop/hal-devel-0.10.0.rpm"
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope call): the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -1244,7 +1253,7 @@ pk_task_resolve_async (PkTask *task, PkBitfield filters, gchar **packages, GCanc
  * pk_task_search_names_async:
  * @task: a valid #PkTask instance
  * @filters: a bitfield of filters that can be used to limit the results
- * @values: search values
+ * @values: (array zero-terminated=1): search values
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope call): the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -1297,7 +1306,7 @@ pk_task_search_names_async (PkTask *task, PkBitfield filters, gchar **values, GC
  * pk_task_search_details_async:
  * @task: a valid #PkTask instance
  * @filters: a bitfield of filters that can be used to limit the results
- * @values: search values
+ * @values: (array zero-terminated=1): search values
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope call): the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -1350,7 +1359,7 @@ pk_task_search_details_async (PkTask *task, PkBitfield filters, gchar **values,
  * pk_task_search_groups_async:
  * @task: a valid #PkTask instance
  * @filters: a bitfield of filters that can be used to limit the results
- * @values: search values
+ * @values: (array zero-terminated=1): search values
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope call): the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -1403,7 +1412,7 @@ pk_task_search_groups_async (PkTask *task, PkBitfield filters, gchar **values, G
  * pk_task_search_files_async:
  * @task: a valid #PkTask instance
  * @filters: a bitfield of filters that can be used to limit the results
- * @values: search values
+ * @values: (array zero-terminated=1): search values
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope call): the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -1455,7 +1464,7 @@ pk_task_search_files_async (PkTask *task, PkBitfield filters, gchar **values, GC
 /**
  * pk_task_get_details_async:
  * @task: a valid #PkTask instance
- * @package_ids: a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
+ * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope call): the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -1506,7 +1515,7 @@ pk_task_get_details_async (PkTask *task, gchar **package_ids, GCancellable *canc
 /**
  * pk_task_get_update_detail_async:
  * @task: a valid #PkTask instance
- * @package_ids: a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
+ * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope call): the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -1557,7 +1566,7 @@ pk_task_get_update_detail_async (PkTask *task, gchar **package_ids, GCancellable
 /**
  * pk_task_download_packages_async:
  * @task: a valid #PkTask instance
- * @package_ids: a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
+ * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
  * @directory: the destination directory
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope call): the function to run when the progress changes
@@ -1662,7 +1671,7 @@ pk_task_get_updates_async (PkTask *task, PkBitfield filters, GCancellable *cance
  * pk_task_get_depends_async:
  * @task: a valid #PkTask instance
  * @filters: a bitfield of filters that can be used to limit the results
- * @package_ids: a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
+ * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
  * @recursive: if we should recurse to packages that depend on other packages
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope call): the function to run when the progress changes
@@ -1768,7 +1777,7 @@ pk_task_get_packages_async (PkTask *task, PkBitfield filters, GCancellable *canc
  * pk_task_get_requires_async:
  * @task: a valid #PkTask instance
  * @filters: a bitfield of filters that can be used to limit the results
- * @package_ids: a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
+ * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
  * @recursive: if we should return packages that depend on the ones we do
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope call): the function to run when the progress changes
@@ -1824,7 +1833,7 @@ pk_task_get_requires_async (PkTask *task, PkBitfield filters, gchar **package_id
  * @task: a valid #PkTask instance
  * @filters: a bitfield of filters that can be used to limit the results
  * @provides: a #PkProvidesEnum type
- * @values: values to search for
+ * @values: (array zero-terminated=1): values to search for
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope call): the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
@@ -1877,7 +1886,7 @@ pk_task_what_provides_async (PkTask *task, PkBitfield filters, PkProvidesEnum pr
 /**
  * pk_task_get_files_async:
  * @task: a valid #PkTask instance
- * @package_ids: a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
+ * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope call): the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
