@@ -163,6 +163,7 @@ pk_backend_spawn_parse_stdout (PkBackendSpawn *backend_spawn, const gchar *line,
 	gchar *command;
 	gchar *text;
 	gboolean ret = TRUE;
+	guint64 speed;
 	PkInfoEnum info;
 	PkRestartEnum restart;
 	PkGroupEnum group;
@@ -394,6 +395,21 @@ pk_backend_spawn_parse_stdout (PkBackendSpawn *backend_spawn, const gchar *line,
 			goto out;
 		}
 		pk_backend_set_status (priv->backend, status_enum);
+	} else if (g_strcmp0 (command, "speed") == 0) {
+		if (size != 2) {
+			g_set_error (error, 1, 0, "invalid command'%s', size %i", command, size);
+			ret = FALSE;
+			goto out;
+		}
+		ret = egg_strtouint64 (sections[1], &speed);
+		if (!ret) {
+			g_set_error (error, 1, 0,
+				     "failed to parse speed: '%s'",
+				     sections[1]);
+			ret = FALSE;
+			goto out;
+		}
+		pk_backend_set_speed (priv->backend, speed);
 	} else if (g_strcmp0 (command, "allow-cancel") == 0) {
 		if (size != 2) {
 			g_set_error (error, 1, 0, "invalid command'%s', size %i", command, size);
@@ -684,7 +700,11 @@ pk_backend_spawn_get_envp (PkBackendSpawn *backend_spawn)
 {
 	gchar **envp;
 	gchar *proxy_http;
+	gchar *proxy_https;
 	gchar *proxy_ftp;
+	gchar *proxy_socks;
+	gchar *no_proxy;
+	gchar *pac;
 	gchar *locale;
 	gchar *line;
 	gchar *uri;
@@ -726,6 +746,15 @@ pk_backend_spawn_get_envp (PkBackendSpawn *backend_spawn)
 		g_free (uri);
 	}
 
+	/* https_proxy */
+	proxy_https = pk_backend_get_proxy_https (priv->backend);
+	if (!egg_strzero (proxy_https)) {
+		uri = pk_backend_spawn_convert_uri (proxy_https);
+		line = g_strdup_printf ("%s=%s", "https_proxy", uri);
+		g_ptr_array_add (array, line);
+		g_free (uri);
+	}
+
 	/* ftp_proxy */
 	proxy_ftp = pk_backend_get_proxy_ftp (priv->backend);
 	if (!egg_strzero (proxy_ftp)) {
@@ -735,6 +764,33 @@ pk_backend_spawn_get_envp (PkBackendSpawn *backend_spawn)
 		g_free (uri);
 	}
 
+	/* socks_proxy */
+	proxy_socks = pk_backend_get_proxy_socks (priv->backend);
+	if (!egg_strzero (proxy_socks)) {
+		uri = pk_backend_spawn_convert_uri (proxy_socks);
+		line = g_strdup_printf ("%s=%s", "socks_proxy", uri);
+		g_ptr_array_add (array, line);
+		g_free (uri);
+	}
+
+	/* no_proxy */
+	no_proxy = pk_backend_get_no_proxy (priv->backend);
+	if (!egg_strzero (no_proxy)) {
+		uri = pk_backend_spawn_convert_uri (no_proxy);
+		line = g_strdup_printf ("%s=%s", "no_proxy", uri);
+		g_ptr_array_add (array, line);
+		g_free (uri);
+	}
+
+	/* pac */
+	pac = pk_backend_get_pac (priv->backend);
+	if (!egg_strzero (pac)) {
+		uri = pk_backend_spawn_convert_uri (pac);
+		line = g_strdup_printf ("%s=%s", "pac", uri);
+		g_ptr_array_add (array, line);
+		g_free (uri);
+	}
+
 	/* LANG */
 	locale = pk_backend_get_locale (priv->backend);
 	if (!egg_strzero (locale)) {
@@ -784,7 +840,11 @@ pk_backend_spawn_get_envp (PkBackendSpawn *backend_spawn)
 	g_ptr_array_unref (array);
 
 	g_free (proxy_http);
+	g_free (proxy_https);
 	g_free (proxy_ftp);
+	g_free (proxy_socks);
+	g_free (no_proxy);
+	g_free (pac);
 	g_free (locale);
 	g_free (eulas);
 	g_free (transaction_id);
