@@ -492,6 +492,9 @@ pk_engine_suggest_daemon_quit (PkEngine *engine, GError **error)
 
 	g_return_val_if_fail (PK_IS_ENGINE (engine), FALSE);
 
+	/* attempt to kill background tasks */
+	pk_transaction_list_cancel_background (engine->priv->transaction_list);
+
 	/* can we exit straight away */
 	size = pk_transaction_list_get_size (engine->priv->transaction_list);
 	if (size == 0) {
@@ -511,14 +514,26 @@ pk_engine_suggest_daemon_quit (PkEngine *engine, GError **error)
  * pk_engine_set_proxy_internal:
  **/
 static gboolean
-pk_engine_set_proxy_internal (PkEngine *engine, const gchar *sender, const gchar *proxy_http, const gchar *proxy_ftp)
+pk_engine_set_proxy_internal (PkEngine *engine, const gchar *sender,
+			      const gchar *proxy_http,
+			      const gchar *proxy_https,
+			      const gchar *proxy_ftp,
+			      const gchar *proxy_socks,
+			      const gchar *no_proxy,
+			      const gchar *pac)
 {
 	gboolean ret;
 	guint uid;
 	gchar *session = NULL;
 
 	/* try to set the new proxy */
-	ret = pk_backend_set_proxy (engine->priv->backend, proxy_http, proxy_ftp);
+	ret = pk_backend_set_proxy (engine->priv->backend,
+				    proxy_http,
+				    proxy_https,
+				    proxy_ftp,
+				    proxy_socks,
+				    no_proxy,
+				    pac);
 	if (!ret) {
 		g_warning ("setting the proxy failed");
 		goto out;
@@ -539,7 +554,14 @@ pk_engine_set_proxy_internal (PkEngine *engine, const gchar *sender, const gchar
 	}
 
 	/* save to database */
-	ret = pk_transaction_db_set_proxy (engine->priv->transaction_db, uid, session, proxy_http, proxy_ftp);
+	ret = pk_transaction_db_set_proxy (engine->priv->transaction_db,
+					   uid, session,
+					   proxy_http,
+					   proxy_https,
+					   proxy_ftp,
+					   proxy_socks,
+					   no_proxy,
+					   pac);
 	if (!ret) {
 		g_warning ("failed to save the proxy in the database");
 		goto out;
@@ -556,6 +578,10 @@ typedef struct {
 	gchar			*sender;
 	gchar			*value1;
 	gchar			*value2;
+	gchar			*value3;
+	gchar			*value4;
+	gchar			*value5;
+	gchar			*value6;
 } PkEngineDbusState;
 #endif
 
@@ -564,7 +590,9 @@ typedef struct {
  * pk_engine_action_obtain_authorization:
  **/
 static void
-pk_engine_action_obtain_proxy_authorization_finished_cb (PolkitAuthority *authority, GAsyncResult *res, PkEngineDbusState *state)
+pk_engine_action_obtain_proxy_authorization_finished_cb (PolkitAuthority *authority,
+							 GAsyncResult *res,
+							 PkEngineDbusState *state)
 {
 	PolkitAuthorizationResult *result;
 	GError *error_local = NULL;
@@ -578,7 +606,8 @@ pk_engine_action_obtain_proxy_authorization_finished_cb (PolkitAuthority *author
 	/* failed */
 	if (result == NULL) {
 		error = g_error_new (PK_ENGINE_ERROR, PK_ENGINE_ERROR_CANNOT_SET_PROXY,
-				     "setting the proxy failed, could not check for auth: %s", error_local->message);
+				     "setting the proxy failed, could not check for auth: %s",
+				     error_local->message);
 		dbus_g_method_return_error (state->context, error);
 		g_error_free (error_local);
 		goto out;
@@ -600,7 +629,13 @@ pk_engine_action_obtain_proxy_authorization_finished_cb (PolkitAuthority *author
 	}
 
 	/* try to set the new proxy and save to database */
-	ret = pk_engine_set_proxy_internal (state->engine, state->sender, state->value1, state->value2);
+	ret = pk_engine_set_proxy_internal (state->engine, state->sender,
+					    state->value1,
+					    state->value2,
+					    state->value3,
+					    state->value4,
+					    state->value5,
+					    state->value6);
 	if (!ret) {
 		error = g_error_new_literal (PK_ENGINE_ERROR, PK_ENGINE_ERROR_CANNOT_SET_PROXY,
 					     "setting the proxy failed");
@@ -610,7 +645,11 @@ pk_engine_action_obtain_proxy_authorization_finished_cb (PolkitAuthority *author
 
 	/* only set after the auth success */
 	g_debug ("changing http proxy to %s for %s", state->value1, state->sender);
-	g_debug ("changing ftp proxy to %s for %s", state->value2, state->sender);
+	g_debug ("changing https proxy to %s for %s", state->value2, state->sender);
+	g_debug ("changing ftp proxy to %s for %s", state->value3, state->sender);
+	g_debug ("changing socks proxy to %s for %s", state->value4, state->sender);
+	g_debug ("changing no proxy to %s for %s", state->value5, state->sender);
+	g_debug ("changing PAC proxy to %s for %s", state->value6, state->sender);
 
 	/* all okay */
 	dbus_g_method_return (state->context);
@@ -631,13 +670,23 @@ out:
  * pk_engine_is_proxy_unchanged:
  **/
 static gboolean
-pk_engine_is_proxy_unchanged (PkEngine *engine, const gchar *sender, const gchar *proxy_http, const gchar *proxy_ftp)
+pk_engine_is_proxy_unchanged (PkEngine *engine, const gchar *sender,
+			      const gchar *proxy_http,
+			      const gchar *proxy_https,
+			      const gchar *proxy_ftp,
+			      const gchar *proxy_socks,
+			      const gchar *no_proxy,
+			      const gchar *pac)
 {
 	guint uid;
 	gboolean ret = FALSE;
 	gchar *session = NULL;
 	gchar *proxy_http_tmp = NULL;
+	gchar *proxy_https_tmp = NULL;
 	gchar *proxy_ftp_tmp = NULL;
+	gchar *proxy_socks_tmp = NULL;
+	gchar *no_proxy_tmp = NULL;
+	gchar *pac_tmp = NULL;
 
 	/* get uid */
 	uid = pk_dbus_get_uid (engine->priv->dbus, sender);
@@ -654,18 +703,34 @@ pk_engine_is_proxy_unchanged (PkEngine *engine, const gchar *sender, const gchar
 	}
 
 	/* find out if they are the same as what we tried to set before */
-	ret = pk_transaction_db_get_proxy (engine->priv->transaction_db, uid, session, &proxy_http_tmp, &proxy_ftp_tmp);
+	ret = pk_transaction_db_get_proxy (engine->priv->transaction_db,
+					   uid,
+					   session,
+					   &proxy_http_tmp,
+					   &proxy_https_tmp,
+					   &proxy_ftp_tmp,
+					   &proxy_socks_tmp,
+					   &no_proxy_tmp,
+					   &pac_tmp);
 	if (!ret)
 		goto out;
 
 	/* are different? */
 	if (g_strcmp0 (proxy_http_tmp, proxy_http) != 0 ||
-	    g_strcmp0 (proxy_ftp_tmp, proxy_ftp) != 0)
+	    g_strcmp0 (proxy_https_tmp, proxy_https) != 0 ||
+	    g_strcmp0 (proxy_ftp_tmp, proxy_ftp) != 0 ||
+	    g_strcmp0 (proxy_socks_tmp, proxy_socks) != 0 ||
+	    g_strcmp0 (no_proxy_tmp, no_proxy) != 0 ||
+	    g_strcmp0 (pac_tmp, pac) != 0)
 		ret = FALSE;
 out:
 	g_free (session);
 	g_free (proxy_http_tmp);
+	g_free (proxy_https_tmp);
 	g_free (proxy_ftp_tmp);
+	g_free (proxy_socks_tmp);
+	g_free (no_proxy_tmp);
+	g_free (pac_tmp);
 	return ret;
 }
 
@@ -673,7 +738,14 @@ out:
  * pk_engine_set_proxy:
  **/
 void
-pk_engine_set_proxy (PkEngine *engine, const gchar *proxy_http, const gchar *proxy_ftp, DBusGMethodInvocation *context)
+pk_engine_set_proxy (PkEngine *engine,
+		     const gchar *proxy_http,
+		     const gchar *proxy_https,
+		     const gchar *proxy_ftp,
+		     const gchar *proxy_socks,
+		     const gchar *no_proxy,
+		     const gchar *pac,
+		     DBusGMethodInvocation *context)
 {
 	guint len;
 	GError *error = NULL;
@@ -681,7 +753,6 @@ pk_engine_set_proxy (PkEngine *engine, const gchar *proxy_http, const gchar *pro
 	gchar *sender = NULL;
 #ifdef USE_SECURITY_POLKIT
 	PolkitSubject *subject;
-	PolkitDetails *details;
 	PkEngineDbusState *state;
 #endif
 	g_return_if_fail (PK_IS_ENGINE (engine));
@@ -697,7 +768,9 @@ pk_engine_set_proxy (PkEngine *engine, const gchar *proxy_http, const gchar *pro
 	/* check length of http */
 	len = egg_strlen (proxy_http, 1024);
 	if (len == 1024) {
-		error = g_error_new (PK_ENGINE_ERROR, PK_ENGINE_ERROR_CANNOT_SET_PROXY, "%s", "http proxy was too long");
+		error = g_error_new_literal (PK_ENGINE_ERROR,
+					     PK_ENGINE_ERROR_CANNOT_SET_PROXY,
+					     "http proxy was too long");
 		dbus_g_method_return_error (context, error);
 		goto out;
 	}
@@ -705,7 +778,9 @@ pk_engine_set_proxy (PkEngine *engine, const gchar *proxy_http, const gchar *pro
 	/* check length of ftp */
 	len = egg_strlen (proxy_ftp, 1024);
 	if (len == 1024) {
-		error = g_error_new (PK_ENGINE_ERROR, PK_ENGINE_ERROR_CANNOT_SET_PROXY, "%s", "ftp proxy was too long");
+		error = g_error_new_literal (PK_ENGINE_ERROR,
+					     PK_ENGINE_ERROR_CANNOT_SET_PROXY,
+					     "ftp proxy was too long");
 		dbus_g_method_return_error (context, error);
 		goto out;
 	}
@@ -714,7 +789,13 @@ pk_engine_set_proxy (PkEngine *engine, const gchar *proxy_http, const gchar *pro
 	sender = dbus_g_method_get_sender (context);
 
 	/* is exactly the same proxy? */
-	ret = pk_engine_is_proxy_unchanged (engine, sender, proxy_http, proxy_ftp);
+	ret = pk_engine_is_proxy_unchanged (engine, sender,
+					    proxy_http,
+					    proxy_https,
+					    proxy_ftp,
+					    proxy_socks,
+					    no_proxy,
+					    pac);
 	if (ret) {
 		g_debug ("not changing proxy as the same as before");
 		dbus_g_method_return (context);
@@ -725,36 +806,41 @@ pk_engine_set_proxy (PkEngine *engine, const gchar *proxy_http, const gchar *pro
 	/* check subject */
 	subject = polkit_system_bus_name_new (sender);
 
-	/* insert details about the authorization */
-	details = polkit_details_new ();
-	polkit_details_insert (details, "role", pk_role_enum_to_string (PK_ROLE_ENUM_UNKNOWN));
-
 	/* cache state */
 	state = g_new0 (PkEngineDbusState, 1);
 	state->context = context;
 	state->engine = g_object_ref (engine);
 	state->sender = g_strdup (sender);
 	state->value1 = g_strdup (proxy_http);
-	state->value2 = g_strdup (proxy_ftp);
+	state->value2 = g_strdup (proxy_https);
+	state->value3 = g_strdup (proxy_ftp);
+	state->value4 = g_strdup (proxy_socks);
+	state->value5 = g_strdup (no_proxy);
+	state->value6 = g_strdup (pac);
 
 	/* do authorization async */
 	polkit_authority_check_authorization (engine->priv->authority, subject,
 					      "org.freedesktop.packagekit.system-network-proxy-configure",
-					      details,
+					      NULL,
 					      POLKIT_CHECK_AUTHORIZATION_FLAGS_ALLOW_USER_INTERACTION,
 					      NULL,
 					      (GAsyncReadyCallback) pk_engine_action_obtain_proxy_authorization_finished_cb,
 					      state);
-
-	/* check_authorization ref's this */
-	g_object_unref (details);
 #else
 	g_warning ("*** THERE IS NO SECURITY MODEL BEING USED!!! ***");
 
 	/* try to set the new proxy and save to database */
-	ret = pk_engine_set_proxy_internal (engine, sender, proxy_http, proxy_ftp);
+	ret = pk_engine_set_proxy_internal (engine, sender,
+					    proxy_http,
+					    proxy_https,
+					    proxy_ftp,
+					    proxy_socks,
+					    no_proxy,
+					    pac);
 	if (!ret) {
-		error = g_error_new (PK_ENGINE_ERROR, PK_ENGINE_ERROR_CANNOT_SET_PROXY, "%s", "setting the proxy failed");
+		error = g_error_new_literal (PK_ENGINE_ERROR,
+					     PK_ENGINE_ERROR_CANNOT_SET_PROXY,
+					     "setting the proxy failed");
 		dbus_g_method_return_error (context, error);
 		goto out;
 	}
@@ -820,7 +906,9 @@ out:
  * pk_engine_action_obtain_authorization:
  **/
 static void
-pk_engine_action_obtain_root_authorization_finished_cb (PolkitAuthority *authority, GAsyncResult *res, PkEngineDbusState *state)
+pk_engine_action_obtain_root_authorization_finished_cb (PolkitAuthority *authority,
+							GAsyncResult *res,
+							PkEngineDbusState *state)
 {
 	PolkitAuthorizationResult *result;
 	GError *error_local = NULL;
@@ -833,8 +921,10 @@ pk_engine_action_obtain_root_authorization_finished_cb (PolkitAuthority *authori
 
 	/* failed */
 	if (result == NULL) {
-		error = g_error_new (PK_ENGINE_ERROR, PK_ENGINE_ERROR_CANNOT_SET_PROXY,
-				     "could not check for auth: %s", error_local->message);
+		error = g_error_new (PK_ENGINE_ERROR,
+				     PK_ENGINE_ERROR_CANNOT_SET_ROOT,
+				     "could not check for auth: %s",
+				     error_local->message);
 		dbus_g_method_return_error (state->context, error);
 		g_error_free (error_local);
 		goto out;
@@ -842,7 +932,8 @@ pk_engine_action_obtain_root_authorization_finished_cb (PolkitAuthority *authori
 
 	/* did not auth */
 	if (!polkit_authorization_result_get_is_authorized (result)) {
-		error = g_error_new_literal (PK_ENGINE_ERROR, PK_ENGINE_ERROR_CANNOT_SET_PROXY,
+		error = g_error_new_literal (PK_ENGINE_ERROR,
+					     PK_ENGINE_ERROR_CANNOT_SET_ROOT,
 					     "failed to obtain auth");
 		dbus_g_method_return_error (state->context, error);
 		goto out;
@@ -851,7 +942,8 @@ pk_engine_action_obtain_root_authorization_finished_cb (PolkitAuthority *authori
 	/* try to set the new root and save to database */
 	ret = pk_engine_set_root_internal (state->engine, state->value1, state->sender);
 	if (!ret) {
-		error = g_error_new_literal (PK_ENGINE_ERROR, PK_ENGINE_ERROR_CANNOT_SET_PROXY,
+		error = g_error_new_literal (PK_ENGINE_ERROR,
+					     PK_ENGINE_ERROR_CANNOT_SET_ROOT,
 					     "setting the root failed");
 		dbus_g_method_return_error (state->context, error);
 		goto out;
@@ -926,7 +1018,6 @@ pk_engine_set_root (PkEngine *engine, const gchar *root, DBusGMethodInvocation *
 	gchar *sender = NULL;
 #ifdef USE_SECURITY_POLKIT
 	PolkitSubject *subject;
-	PolkitDetails *details;
 	PkEngineDbusState *state;
 #endif
 	g_return_if_fail (PK_IS_ENGINE (engine));
@@ -981,10 +1072,6 @@ pk_engine_set_root (PkEngine *engine, const gchar *root, DBusGMethodInvocation *
 	/* check subject */
 	subject = polkit_system_bus_name_new (sender);
 
-	/* insert details about the authorization */
-	details = polkit_details_new ();
-	polkit_details_insert (details, "role", pk_role_enum_to_string (PK_ROLE_ENUM_UNKNOWN));
-
 	/* cache state */
 	state = g_new0 (PkEngineDbusState, 1);
 	state->context = context;
@@ -995,14 +1082,11 @@ pk_engine_set_root (PkEngine *engine, const gchar *root, DBusGMethodInvocation *
 	/* do authorization async */
 	polkit_authority_check_authorization (engine->priv->authority, subject,
 					      "org.freedesktop.packagekit.system-change-install-root",
-					      details,
+					      NULL,
 					      POLKIT_CHECK_AUTHORIZATION_FLAGS_ALLOW_USER_INTERACTION,
 					      NULL,
 					      (GAsyncReadyCallback) pk_engine_action_obtain_root_authorization_finished_cb,
 					      state);
-
-	/* check_authorization ref's this */
-	g_object_unref (details);
 #else
 	g_warning ("*** THERE IS NO SECURITY MODEL BEING USED!!! ***");
 
@@ -1395,8 +1479,12 @@ pk_engine_init (PkEngine *engine)
 	gchar *filename;
 	gchar *root;
 	gchar *proxy_http;
+	gchar *proxy_https;
 	gchar *proxy_ftp;
-#ifdef USE_SECURITY_POLKIT_NEW
+	gchar *proxy_socks;
+	gchar *no_proxy;
+	gchar *pac;
+#if defined(USE_SECURITY_POLKIT_NEW) && defined(HAVE_POLKIT_AUTHORITY_GET_SYNC)
 	GError *error = NULL;
 #endif
 
@@ -1489,7 +1577,7 @@ pk_engine_init (PkEngine *engine)
 
 #ifdef USE_SECURITY_POLKIT
 	/* protect the session SetProxy with a PolicyKit action */
-#ifdef USE_SECURITY_POLKIT_NEW
+#if defined(USE_SECURITY_POLKIT_NEW) && defined(HAVE_POLKIT_AUTHORITY_GET_SYNC)
 	engine->priv->authority = polkit_authority_get_sync (NULL, &error);
 	if (engine->priv->authority == NULL) {
 		g_error ("failed to get pokit authority: %s", error->message);
@@ -1508,15 +1596,29 @@ pk_engine_init (PkEngine *engine)
 
 	/* set the default proxy */
 	proxy_http = pk_conf_get_string (engine->priv->conf, "ProxyHTTP");
+	proxy_https = pk_conf_get_string (engine->priv->conf, "ProxyHTTPS");
 	proxy_ftp = pk_conf_get_string (engine->priv->conf, "ProxyFTP");
-	pk_backend_set_proxy (engine->priv->backend, proxy_http, proxy_ftp);
+	proxy_socks = pk_conf_get_string (engine->priv->conf, "ProxySOCKS");
+	no_proxy = pk_conf_get_string (engine->priv->conf, "NoProxy");
+	pac = pk_conf_get_string (engine->priv->conf, "PAC");
+	pk_backend_set_proxy (engine->priv->backend,
+			      proxy_http,
+			      proxy_https,
+			      proxy_ftp,
+			      proxy_socks,
+			      no_proxy,
+			      pac);
 
-	/* if either of these is set, we ignore the users proxy setting */
-	if (proxy_http != NULL || proxy_ftp != NULL)
+	/* if any of these is set, we ignore the users proxy setting */
+	if (proxy_http != NULL || proxy_https != NULL || proxy_ftp != NULL)
 		engine->priv->using_hardcoded_proxy = TRUE;
 
 	g_free (proxy_http);
+	g_free (proxy_https);
 	g_free (proxy_ftp);
+	g_free (proxy_socks);
+	g_free (no_proxy);
+	g_free (pac);
 
 	/* set the default root */
 	root = pk_conf_get_string (engine->priv->conf, "UseRoot");
