@@ -44,6 +44,9 @@
 #include "pk-proc.h"
 #include "pk-conf.h"
 
+/* for when parsing /etc/login.defs fails */
+#define PK_TRANSACTION_EXTRA_UID_MIN_DEFALT	500
+
 #define PK_POST_TRANS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PK_TYPE_POST_TRANS, PkTransactionExtraPrivate))
 
 struct PkTransactionExtraPrivate
@@ -789,6 +792,37 @@ out:
 	return uid;
 }
 
+static guint
+pk_transaction_extra_get_uid_min (void)
+{
+	gboolean ret;
+	guint i;
+	gchar *data = NULL;
+	gchar **split = NULL;
+	GError *error = NULL;
+	guint uid_min = G_MAXUINT;
+
+	/* get contents */
+	ret = g_file_get_contents ("/etc/login.defs", &data, NULL, &error);
+	if (!ret) {
+		g_warning ("failed to get login UID_MIN: %s",
+			   error->message);
+		g_error_free (error);
+		goto out;
+	}
+	split = g_strsplit (data, "\n", -1);
+	for (i = 0; split[i] != NULL; i++) {
+		if (!g_str_has_prefix (split[i], "UID_MIN"))
+			continue;
+		uid_min = atoi (g_strchug (split[i]+7));
+		break;
+	}
+out:
+	g_free (data);
+	g_strfreev (split);
+	return uid_min;
+}
+
 /**
  * pk_transaction_extra_check_library_restart:
  **/
@@ -805,6 +839,7 @@ pk_transaction_extra_check_library_restart (PkTransactionExtra *extra)
 	GPtrArray *files_system;
 	PkPackage *package;
 	GPtrArray *pids;
+	guint uid_min;
 
 	g_return_val_if_fail (PK_IS_POST_TRANS (extra), FALSE);
 
@@ -820,6 +855,11 @@ pk_transaction_extra_check_library_restart (PkTransactionExtra *extra)
 	/* set status */
 	pk_transaction_extra_set_status_changed (extra, PK_STATUS_ENUM_CHECK_LIBRARIES);
 
+	/* get user UID range */
+	uid_min = pk_transaction_extra_get_uid_min ();
+	if (uid_min == G_MAXUINT)
+		uid_min = PK_TRANSACTION_EXTRA_UID_MIN_DEFALT;
+
 	/* find the package name of each pid */
 	for (i=0; i<pids->len; i++) {
 		pid = GPOINTER_TO_INT (g_ptr_array_index (pids, i));
@@ -841,7 +881,7 @@ pk_transaction_extra_check_library_restart (PkTransactionExtra *extra)
 			cmdline_full = g_strdup_printf ("/usr/bin/%s", cmdline);
 
 		g_debug ("pid=%i: %s (%i)", pid, cmdline_full, uid);
-		if (uid < 500)
+		if (uid < (gint) uid_min)
 			g_ptr_array_add (files_system, cmdline_full);
 		else
 			g_ptr_array_add (files_session, cmdline_full);
@@ -1214,7 +1254,7 @@ pk_transaction_extra_init (PkTransactionExtra *extra)
 	g_debug ("trying to open database '%s'", PK_DESKTOP_DEFAULT_DATABASE);
 	rc = sqlite3_open (PK_DESKTOP_DEFAULT_DATABASE, &extra->priv->db);
 	if (rc != 0) {
-		g_warning ("Can't open database: %s\n", sqlite3_errmsg (extra->priv->db));
+		g_warning ("Can't open desktop database: %s\n", sqlite3_errmsg (extra->priv->db));
 		sqlite3_close (extra->priv->db);
 		extra->priv->db = NULL;
 		return;
